pyprocar.io.qe.QEParser — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# pyprocar.io.qe.QEParser

class pyprocar.io.qe.QEParser(dirname: str = '', scf_in_filename: str = 'scf.in', bands_in_filename: str = 'bands.in', pdos_in_filename: str = 'pdos.in', kpdos_in_filename: str = 'kpdos.in', atomic_proj_xml: str = 'atomic_proj.xml')

  The class is used to parse Quantum Expresso files. The most important objects that comes from this parser are the .ebs and .dos

  Parameters:

    - dirname (str, optional) – Directory path to where calculation took place, by default “”

    - scf_in_filename (str, optional) – The scf filename, by default “scf.in”

    - bands_in_filename (str, optional) – The bands filename in the case of a band structure calculation, by default “bands.in”

    - pdos_in_filename (str, optional) – The pdos filename in the case of a density ofstates calculation, by default “pdos.in”

    - kpdos_in_filename (str, optional) – The kpdos filename, by default “kpdos.in”

    - atomic_proj_xml (str, optional) – The atomic projection xml name. This is located in the where the outdir is and in the {prefix}.save directory, by default “atomic_proj.xml”

  Methods

  `QEParser.__init__`([dirname, ...]) |
  `QEParser.kpoints_cart`() | Returns the kpoints in cartesian coordinates

  Attributes

  `QEParser.final_structure` | Returns a the last element of a list of pyprocar.core.Structure
  `QEParser.initial_structure` | Returns a the first element of a list of pyprocar.core.Structure
  `QEParser.species` | Returns the species of the calculation
  `QEParser.structure` | Returns a the last element of a list of pyprocar.core.Structure
  `QEParser.structures` | Returns a list of pyprocar.core.Structure